summaryrefslogtreecommitdiffstats
path: root/perl-install/install_steps.pm
diff options
context:
space:
mode:
authorFrancois Pons <fpons@mandriva.com>2000-11-24 17:38:52 +0000
committerFrancois Pons <fpons@mandriva.com>2000-11-24 17:38:52 +0000
commit8417092eb2c88112b1949f3046360173ac0d2805 (patch)
treeae1b66d952140e5d3302191ec21d75f67546b7a2 /perl-install/install_steps.pm
parent7ee987e60dcc07fd2fc30040ef288e10d724acd0 (diff)
downloaddrakx-8417092eb2c88112b1949f3046360173ac0d2805.tar
drakx-8417092eb2c88112b1949f3046360173ac0d2805.tar.gz
drakx-8417092eb2c88112b1949f3046360173ac0d2805.tar.bz2
drakx-8417092eb2c88112b1949f3046360173ac0d2805.tar.xz
drakx-8417092eb2c88112b1949f3046360173ac0d2805.zip
added missing portmap.
Diffstat (limited to 'perl-install/install_steps.pm')
-rw-r--r--perl-install/install_steps.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/perl-install/install_steps.pm b/perl-install/install_steps.pm
index 55be9a166..80d9264e6 100644
--- a/perl-install/install_steps.pm
+++ b/perl-install/install_steps.pm
@@ -404,14 +404,14 @@ Consoles 1,3,4,7 may also contain interesting information";
any::writeandclean_ldsoconf($o->{prefix});
log::l("before install packages, after writing ld.so.conf");
#- make sure the services of initscripts have been enabled (or a catastrophic dead will occur).
#- to keep while initscript not cleaned.
run_program::rooted($o->{prefix}, "chkconfig", "--add", "random");
run_program::rooted($o->{prefix}, "chkconfig", "--add", "netfs");
run_program::rooted($o->{prefix}, "chkconfig", "--add", "network");
run_program::rooted($o->{prefix}, "chkconfig", "--add", "rawdevices");
run_program::rooted($o->{prefix}, "chkconfig", "--add", "sound");
run_program::rooted($o->{prefix}, "chkconfig", "--add", "kheader");
+ run_program::rooted($o->{prefix}, "chkconfig", "--add", "portmap");
#- remove the nasty acon...
run_program::rooted($o->{prefix}, "chkconfig", "--del", "acon") unless $ENV{LANGUAGE} =~ /ar/;
@@ -404,14 +404,14 @@ Consoles 1,3,4,7 may also contain interesting information";
any::writeandclean_ldsoconf($o->{prefix});
log::l("before install packages, after writing ld.so.conf");
- #- make sure the services of initscripts have been enabled (or a catastrophic dead will occur).
- #- to keep while initscript not cleaned.
+ #- make sure the services of initscripts/portmap have been enabled (or a catastrophic dead will occur).
run_program::rooted($o->{prefix}, "chkconfig", "--add", "random");
run_program::rooted($o->{prefix}, "chkconfig", "--add", "netfs");